# Functional Environments

### AutoTS Version 0.0.3, 0.0.4 and 0.1.0 Date: Feb 12, 2020
Same as 0.0.2

### AutoTS Version 0.0.2 Date: Jan 11, 2020

```
Python==3.6.8
numpy==1.16.5
pandas==0.25.3
scikit-learn==0.21.3
statsmodels==0.10.1
fbprophet==0.5
holidays==0.9.11
fredapi==0.4.2
```

### AutoTS Version 0.0.2 Date: Jan 11, 2020

```
Python==3.7.4
numpy==1.17.2
pandas==0.25.1
scikit-learn==0.21.3
statsmodels==0.10.1
fbprophet==0.5
holidays==0.9.12
```

### AutoTS Version 0.0.2 Date: Jan 11, 2020
Prints a numpy math warning but still runs.

```
Python==3.7.4
numpy==1.14.6
pandas==0.25.1
scikit-learn==0.22.1
statsmodels==0.10.1
fbprophet==0.5
holidays==0.9.11
fredapi==0.4.2
```